# ADS1015 4 channel differential/single-ended ADC

[![Build Status](https://img.shields.io/github/actions/workflow/status/pimoroni/ads1015-python/test.yml?branch=master)](https://github.com/pimoroni/ads1015-python/actions/workflows/test.yml)
[![Coverage Status](https://coveralls.io/repos/github/pimoroni/ads1015-python/badge.svg?branch=master)](https://coveralls.io/github/pimoroni/ads1015-python?branch=master)
[![PyPi Package](https://img.shields.io/pypi/v/ads1015.svg)](https://pypi.python.org/pypi/ads1015)
[![Python Versions](https://img.shields.io/pypi/pyversions/ads1015.svg)](https://pypi.python.org/pypi/ads1015)

# Installing

Stable library from PyPi:

* Just run `python3 -m pip install ads1015`

Latest/development library from GitHub:

* `git clone https://github.com/pimoroni/ads1015-python`
* `cd ads1015-python`
* `./install.sh --unstable`

